harrier
=======

|BuildStatus| |Coverage|

Static site generator, **in development**.

.. |BuildStatus| image:: https://travis-ci.org/samuelcolvin/harrier.svg?branch=master
   :target: https://travis-ci.org/samuelcolvin/harrier
.. |Coverage| image:: https://codecov.io/gh/samuelcolvin/harrier/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/samuelcolvin/harrier
